DoH

Struct DoH 

pub struct DoH<'a> {
    pub name: String,
    pub type: Option<u32>,
    pub cd: Option<bool>,
    pub ct: Option<String>,
    pub do: Option<bool>,
    pub edns_client_subnet: Option<String>,
    /* private fields */
}

Fields

name: Stringtype: Option<u32>

RR type default = 1

cd: Option<bool>

The checking disabled flag Use true to disable DNSSEC or false to enable DNSSEC validation default = false

ct: Option<String>

Desired content type ct=application/dns-message for binary DNS-message ct=application/x-javascript for JSON text default = empty

do: Option<bool>

DNSSEC OK flag if true, the DNSSEC records will be included in the response (RRSIG, NSEC, NSEC3) or false to ommit these values in the response default = false

edns_client_subnet: Option<String>

Use IP address format with a subnet mask Examples: 1.2.3.4/24, 2001:700:300::/48 default = empty

Implementations

Source

impl<'a> DoH<'a>

pub fn new(name: String) -> Self

pub fn set_base_url(self, value: &'a str) -> Self

pub fn set_ct(self, value: String) -> Self

Sets the desired content type

pub fn set_type(self, value: u32) -> Self

Sets the RR type

pub fn set_cd(self, value: bool) -> Self

Disable or enable DNSSEC check

pub fn set_do(self, value: bool) -> Self

Include or ommit DNSSEC records

pub fn set_edns_client_subnet(self, value: String) -> Self

Include or ommit DNSSEC records

pub async fn resolve(&self) -> Result<Dns>